#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fourmolu
version:              0.14.0.0
visibility:           public
id:                   fourmolu-0.14.0.0-sPV4VZpHpXKSci53vK0oW
key:                  fourmolu-0.14.0.0-sPV4VZpHpXKSci53vK0oW
license:              BSD-3-Clause
maintainer:
    Matt Parsons <parsonsmatt@gmail.com>
    George Thomas <georgefsthomas@gmail.com>
    Brandon Chinn <brandonchinn178@gmail.com>

homepage:             https://github.com/fourmolu/fourmolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  0faa69cf91649c4dbfe5658a05f50b0e
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff.ParseResult Ormolu.Diff.Text
    Ormolu.Exception Ormolu.Fixity Ormolu.Fixity.Imports
    Ormolu.Fixity.Internal Ormolu.Fixity.Parser Ormolu.Fixity.Printer
    Ormolu.Imports Ormolu.Parser Ormolu.Parser.CommentStream
    Ormolu.Parser.Pragma Ormolu.Parser.Result Ormolu.Printer
    Ormolu.Printer.Combinators Ormolu.Printer.Comments
    Ormolu.Printer.Internal Ormolu.Printer.Meat.Common
    Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.OpTree
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Preprocess Ormolu.Terminal
    Ormolu.Terminal.QualifiedDo Ormolu.Utils Ormolu.Utils.Cabal
    Ormolu.Utils.Fixity Ormolu.Utils.IO Paths_fourmolu

hidden-modules:       Ormolu.Config.Gen GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.6.6/site-local/fourmolu-0.14.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/fourmolu-0.14.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/fourmolu-0.14.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fourmolu
hs-libraries:         HSfourmolu-0.14.0.0-sPV4VZpHpXKSci53vK0oW
depends:
    Cabal-syntax-3.10.3.0 Diff-0.5-I5m4girc8oXI0fYmz1F9Wy
    MemoTrie-0.6.11-EaBNTNVXiKB2QKERc208Wn
    aeson-2.2.2.0-DAWEUfqGTZl4JS91alOoes
    ansi-terminal-1.1-D07LgEFqBSsB16qPkFlGoJ array-0.5.6.0
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    ghc-lib-parser-9.6.6.20240701-5tnwV8Oo0yDEfyybbFjRdd
    megaparsec-9.7.0-BQSYqoXI2TY61xEmJ10u8L mtl-2.3.1
    scientific-0.3.8.1-5xEN5FH7FNLBtMgMgahhk5
    syb-0.7.3-BHNsCpgEnKh5sSWu1sJK4W text-2.0.2
    yaml-0.11.11.2-8eLFXIdsE0bB7sOWbJDpuK

haddock-interfaces:   /usr/share/doc/haskell-fourmolu/html/fourmolu.haddock
haddock-html:         /usr/share/doc/haskell-fourmolu/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

